Code architecture
=================

Slides of the tutorial
----------------------

See `this file <https://www.aquila-consortium.org/wiki/index.php/File:ARES_code.pdf>`__.
Some of these slides are starting to get outdated. Check the doc pages in case of doubt.
